@@ -32,6 +32,7 @@
 #include "aflib/aflibConfig.h"
 #include "aflib/aflibFile.h"
 #include "aflib/aflibData.h"
+#include "aflib/aflibFile.h"
 #include "aflib/aflibAudioFile.h"
 #include "aflib/aflibAudioPitch.h"
 #include "aflib/aflibAudioSampleRateCvt.h"
@@ -51,7 +52,7 @@
 using std::list;
 
 
-#define PLAY_DELTA 1024 * 5
+#define PLAY_DELTA 1024 * 4
 #define MP3_DATA_CFG "otrplayer.cfg"
 #define FILE_LINE 0
 #define INFO_LINE 1
@@ -165,7 +166,7 @@ otrplayer::about()
       std::cout << "otrplayer: about called" << std::endl;
    QMessageBox::about(this, tr("About Otrplayer"),
       tr("<img src=\"/usr/share/icons/hicolor/scalable/hildon/otrplayer.png\" align=\"middle\" />"
-      "<h1 align=\"center\"><b>Otrplayer 0.4</b></h1>"
+      "<h1 align=\"center\"><b>Otrplayer 0.41</b></h1>"
       "<h5 align=\"center\">OTR Audio Player</h5>"
       "<h5 align=\"center\">(C) 2009 Bruce Forsberg</h5>"
       "<h5 align=\"center\">http://otrplayer.garage.maemo.org</h5>"));
@@ -352,9 +353,9 @@ void
 otrplayer::getFiles()
 {
    QStringList  lst, tree;
-   QStringList::Iterator  it, itt;
+   QStringList::Iterator  it, itt, it_off;
    MyQ3ListViewItem  *item = NULL;
-   aflibAudioFile  *temp = NULL;
+   aflibFile  *temp = NULL;
    aflibConfig  input_config;
    aflibStatus  status;
    int          value;
@@ -366,6 +367,7 @@ otrplayer::getFiles()
    static bool  madplay_found = TRUE;
    static bool  displayed_warning = FALSE;
    QStringList  file_list;
+   QStringList  offset_list;
    QStringList  old_list;
    QString      dir_save;
    QString      file_save;
@@ -410,6 +412,7 @@ otrplayer::getFiles()
 
    // Clear all previous entries
    file_list.clear();
+   offset_list.clear();
 
    // Clear all entries in list GUI
    playList->clear();
@@ -435,49 +438,53 @@ otrplayer::getFiles()
 
    if (_debug)
       std::cout << "getFiles: get mp3 files from each directory" << std::endl;
+   QStringList filters;
+   filters << "*.mp3" << "*.ogg" << "*.wav";
    // Loop for every directory tree
    for (itt = lst.begin(); itt != lst.end(); ++itt)
    {
       QDir  dir(*itt);
-      QStringList filters;
 
-      filters << "*.mp3" << "*.ogg" << "*.wav";
       dir.setNameFilters(filters);
       tmp_lst = dir.entryList();
+      filepath = (*itt);
+      filepath.append("/");
 
       for (it = tmp_lst.begin(); it != tmp_lst.end(); ++it)
-      {
-         filepath = (*itt);
-         filepath.append("/");
-         filepath.append(*it);
-
-         file_list.append(filepath);
-      }
+         file_list.append(filepath + *it);
    }
 
    if (_debug)
       std::cout << "getFiles: Update list of files" << std::endl;
    // Update list of files
-   _otr_file->process(file_list);
+   _otr_file->process(file_list, offset_list);
+   if (_debug)
+     std::cout << "getFiles: Done Update list of files" << std::endl;
 
-   for (it = file_list.begin(); it != file_list.end(); ++it)
+   if (_debug)
+      std::cout << "getFiles: Total number of files are: " << file_list.size() << std::endl;
+
+   for (it = file_list.begin(), it_off = offset_list.begin();
+        it != file_list.end(); ++it, ++it_off)
    {
-      QString  str1, str2, str3, secs, mins;
-      QString  latin_str = (*it).toLatin1();
+      QString  str1, str2, str3;
       QString  local_str = (*it).toLocal8Bit();
 
+#if 0
       if (_debug)
       {
+         QString  latin_str = (*it).toLatin1();
          std::cout << "getFiles: get info for:" << latin_str.toStdString() << std::endl;
          std::cout << "getFiles: local8bit:" << local_str.toStdString() << std::endl;
       }
+#endif
 
       // IF an ogg extension then use AUTO type
       if ((*it).endsWith(".mp3", Qt::CaseInsensitive) == true)
-         temp = new aflibAudioFile(AFLIB_MPEG_TYPE, local_str.toStdString(),
+         temp = aflibFile::open(AFLIB_MPEG_TYPE, local_str.toStdString(),
                &input_config, &status);
       else
-         temp = new aflibAudioFile(AFLIB_AUTO_TYPE, local_str.toStdString(),
+         temp = aflibFile::open(AFLIB_AUTO_TYPE, local_str.toStdString(),
                &input_config, &status);
 
       // Did we not find madplay
@@ -518,19 +525,18 @@ otrplayer::getFiles()
 
          if (input_config.getSamplesPerSecond() != 0)
          {
+            long off = (*it_off).toLong();
+
             // IF -1 we are at end of file
-            if (_otr_file->getOffset(*it) == -1)
+            if (off == -1)
                sec = total_sec;
             else
-               sec = _otr_file->getOffset(*it) / input_config.getSamplesPerSecond();
+               sec = off / input_config.getSamplesPerSecond();
          }
          else
             sec = 0;
          secondsToQString(sec, str2);
 
-         if (_debug)
-            std::cout << "getFiles: Update info in list box" << std::endl;
-
          str.setNum(value);
          str3.setNum(input_config.getSamplesPerSecond());
 
