@@ -80,7 +80,8 @@ otrplayerfile::~otrplayerfile()
 
 void
 otrplayerfile::process(
-   QStringList&  lst)
+   QStringList&  lst,
+   QStringList&  offsets)
 {
    QString str;
    QStringList  io_files;
@@ -113,6 +114,8 @@ otrplayerfile::process(
          io_files.append(*it);
          io_offset.append("0");
          io_date.append(info.lastModified().toString());
+         // Update offset for returned list
+         offsets.append("0");
       }
       // ELSE if found check date
       else
@@ -132,6 +135,14 @@ otrplayerfile::process(
             io_files.append(*it);
             io_offset.append("0");
             io_date.append(info.lastModified().toString());
+
+            // Update offset for returned list
+            offsets.append("0");
+         }
+         else
+         {
+            // Update offset for returned list
+            offsets.append(io_offset.at(index));
          }
       }
    }
