@@ -50,7 +50,8 @@ public:
 
     void
     process(
-       QStringList& files);
+       QStringList& files,
+       QStringList& offsets);
 
     long
     getOffset(QString& file);
