@@ -94,17 +94,34 @@ aflibMadFile::afopen(
 {
    // This function will open an existing MP3 file.
 
-   string cmd_str, temppath;
+   string cmd_str;
    aflibConfig  input_cfg(*cfg);
    char  buf[10240];
-   char temp[] = "mpeg-XXXXXX";
    long info_size = 0;
    aflibData  data(1);
    char    *temp_buf;
    struct stat  stat_buf;
    long long    samples;
-   int  status_system;
 
+   // USING popen
+   cmd_str = "madplay";
+   cmd_str += " -v --time=00:00:00.001 --output=raw:";
+   cmd_str += "/dev/null \"";
+   cmd_str += file;
+   cmd_str += "\" 2>&1";
+
+   _fd = popen(cmd_str.c_str(), "r");
+   if (_fd == NULL)
+      return (AFLIB_ERROR_OPEN);
+
+   info_size = fread(buf,1,200,_fd);  
+   pclose(_fd);
+   _fd = NULL;
+
+#if 0
+   string temppath;
+   char temp[] = "mpeg-XXXXXX";
+   int  status_system;
 
    if ( mktemp(temp) == NULL ) return (AFLIB_ERROR_OPEN);
    temppath = TEMP_DIR; 
@@ -130,6 +147,7 @@ aflibMadFile::afopen(
    fclose(_fd);
    _fd = NULL;
    unlink(temppath.c_str());
+#endif
 
    buf[info_size] = 0;
 
